### PySAL (ESDA) Tools

Spatial autocorrelation and clustering tools powered by PySAL/ESDA.

**Spatial Autocorrelation:**

- [morans_i](morans_i.md)
- [gearys_c](gearys_c.md)
- [getis_ord_g](getis_ord_g.md)
- [gamma_statistic](gamma_statistic.md)

**Local Statistics:**

- [moran_local](moran_local.md)
- [getis_ord_g_local](getis_ord_g_local.md)
- [join_counts_local](join_counts_local.md)

**Global Statistics:**

- [join_counts](join_counts.md)

**Clustering:**

- [adbscan](adbscan.md)

**Spatial Weights:**

- [weights_from_shapefile](weights_from_shapefile.md)
- [distance_band_weights](distance_band_weights.md)
- [knn_weights](knn_weights.md)
- [build_and_transform_weights](build_and_transform_weights.md)
- [build_transform_and_save_weights](build_transform_and_save_weights.md)

**Spatial Regression:**

- [ols_with_spatial_diagnostics_safe](ols_with_spatial_diagnostics_safe.md)
- [gm_lag](gm_lag.md)

**Spatial-Temporal Analysis:**

- [spatial_markov](spatial_markov.md)
- [dynamic_lisa](dynamic_lisa.md)
